********************************************************************
*                                                                  *
* Program name: VENUSCMP.TST  for AIX                              *
*                                                                  *
* Description: Sample MQSC command file that defines sample        *
*              queues and channels used to verify a connection     *
*              between two queue managers                          *
*                                                                  *
* Statement:     Licensed Materials - Property of IBM              *
*                                                                  *
*                                                                  *
*                5622-960 (C) Copyright IBM Corp. 1995, 1996       *
*                                                                  *
*                U.S. Government Users Restricted Rights - use,    *
*                duplication or disclosure restricted by GSA ADP   *
*                Schedule Contract with IBM Corp.                  *
*                                                                  *
*                                                                  *
********************************************************************
*                                                                  *
* Function:                                                        *
*                                                                  *
*                                                                  *
*   VENUSCMP.TST is a sample MQSC command file that creates sample *
*   queues and channels used to verify a connection between two    *
*   queue managers.                                                *
*                                                                  *
*   The verification test assumes that the two queue managers      *
*   are called MARS and VENUS.                                     *
*   A listener is used on the VENUS queue manager.                 *
*   The channels are initiated from the MARS queue manager.        *
*                                                                  *
*   Run this sample MQSC file from the command line  .             *
*                                                                  *
*    runmqsc VENUS <venuscmp.tst > venuscmp.tst                    *
*                                                                  *
********************************************************************

* Define a local transmission queue - messages will be put here
* before being sent to the remote queue manager.
DEFINE QLOCAL('SAMPLE.VENUS.XMIT') REPLACE +
       DESCR('Local transmission queue')  +
       USAGE(XMITQ)


* Define the remote queue.
* The sample application should put messages on to this queue.
DEFINE QREMOTE('SAMPLE.VENUS.REMOTE') REPLACE  +
       DESCR('Remote queue defined on VENUS') +
       DEFPSIST(YES) +
* This is the name of the local queue on the remote machine.
       RNAME('SAMPLE.MARS.LOCAL') +
* This is the name of the queue manager on the remote machine.
       RQMNAME('MARS') +
* This is the name of the local transmission queue to be used.
       XMITQ('SAMPLE.VENUS.XMIT')


* Define the channel that will remove messages from the transmission
* queue SAMPLE.VENUS.XMIT and send them to the remote queue
* manager.
DEFINE CHANNEL ('VENUS.TO.MARS') CHLTYPE(SVR) TRPTYPE(TCP) +
       XMITQ('SAMPLE.VENUS.XMIT') +
       SENDEXIT('mqc_s(mqc_exit)')      +
       DESCR('Server channel for messages to queue manager MARS') +
       REPLACE


* Define the channel that will accept messages from the remote
* queue manager.
DEFINE CHANNEL ('MARS.TO.VENUS')  CHLTYPE(RCVR) TRPTYPE(TCP) +
       RCVEXIT('mqc_r(mqc_exit)')      +
       DESCR('Receiver channel for messages from queue manager MARS') +
       REPLACE


* Define the local queue where the remote machine will place
* its messages.
* The sample application should get messages from this queue.
DEFINE QLOCAL('SAMPLE.VENUS.LOCAL') REPLACE +
       DESCR('Local queue') +
       DEFPSIST(YES)  +
       SHARE
