********************************************************************
*                                                                  *
* Program name: MARSCOMP.TST    for Windows NT                     *
*                                                                  *
* Description: Sample MQSC command file that defines sample queues *
*              and channels used to verify a connection between    *
*              two queue managers using compression exit           *
*                                                                  *
* Statement:     Licensed Materials - Property of IBM              *
*                                                                  *
*                                                                  *
*                5622-960 (C) Copyright IBM Corp. 1995, 1996       *
*                                                                  *
*                U.S. Government Users Restricted Rights - use,    *
*                duplication or disclosure restricted by GSA ADP   *
*                Schedule Contract with IBM Corp.                  *
*                                                                  *
*                                                                  *
********************************************************************
*                                                                  *
* Function:                                                        *
*                                                                  *
*                                                                  *
*   MARSCOMP.TST is a sample MQSC command file that creates sample *
*   queues and channels used to verify a connection between two    *
*   queue managers using compression exits.                        *
*                                                                  *
*   The verification test assumes that the two queue managers      *
*   are called MARS and VENUS.                                     *
*   A listener is used on the VENUS queue manager.                 *
*   The channels are initiated from the MARS queue manager.        *
*                                                                  *
*   You must change the value of the CONNAME attribute in the      *
*   channel definitions (DEFINE CHANNEL commands) to use           *
*   the TCP/IP machine name of the workstation on which the        *
*   VENUS queue manager is running.                                *
*                                                                  *
*   Run this sample MQSC file from the command line  .             *
*                                                                  *
*    runmqsc MARS  <marscomp.tst > marscomp.out                    *
*                                                                  *
********************************************************************

* Define a local transmission queue - messages will be put here
* before being sent to the remote queue manager.
* Note that transmission queues cannot be shared between active
* channels - each active channel must have its own transmission
* queue.
DEFINE QLOCAL('SAMPLE.MARS.XMIT') REPLACE +
       DESCR('Local transmission queue')  +
       USAGE(XMITQ)


* Define the remote queue.
* The sample application should put messages on this queue.
DEFINE QREMOTE('SAMPLE.MARS.REMOTE') REPLACE  +
       DESCR('Remote queue defined on MARS') +
       DEFPSIST(YES) +
* This is the name of the local queue on the remote machine.
       RNAME('SAMPLE.VENUS.LOCAL') +
* This is the name of the queue manager on the remote machine.
       RQMNAME('VENUS') +
* This is the name of the local transmission queue to be used.
       XMITQ('SAMPLE.MARS.XMIT')


* Define the channel that will remove messages from the transmission
* queue SAMPLE.MARS.XMIT and send them to the machine specified
* by CONNAME.
*
* Change CONNAME to the TCP/IP name of the machine where
* the remote queue manager is running.
*
DEFINE CHANNEL ('MARS.TO.VENUS')  CHLTYPE(SDR) TRPTYPE(TCP) +
       XMITQ('SAMPLE.MARS.XMIT') +
       CONNAME('VENUS TCP/IP machine name') +
       SENDEXIT('mqc_sw32(mqc_exit)')    +
       DESCR('Sender channel for messages to queue manager VENUS') +
       REPLACE


* Define the channel that will accept messages from the remote
* queue manager on the machine specified by CONNAME.
*
* Change CONNAME to the TCP/IP name of the machine where
* the remote queue manager is running.
*
DEFINE CHANNEL ('VENUS.TO.MARS') CHLTYPE(RQSTR) TRPTYPE(TCP) +
       CONNAME('VENUS TCP/IP machine name') +
       RCVEXIT('mqc_rw32(mqc_exit)')+
       DESCR('Requester channel for messages from queue manager VENUS') +
       REPLACE


* Define the local queue where the remote machine will place
* its messages.
* The sample application should get messages from this queue.
DEFINE QLOCAL('SAMPLE.MARS.LOCAL') REPLACE +
       DESCR('Local queue') +
       DEFPSIST(YES)  +
       SHARE

